# Generated by roxygen2: do not edit by hand

S3method(as_xml_nodeset,character)
S3method(as_xml_nodeset,glue)
S3method(as_xml_nodeset,list)
S3method(as_xml_nodeset,xml_node)
S3method(as_xml_nodeset,xml_nodeset)
S3method(polish_content_pptx,as_is)
S3method(polish_content_pptx,as_md)
S3method(polish_content_pptx,character)
S3method(polish_content_pptx,data.frame)
S3method(polish_content_pptx,default)
S3method(polish_content_pptx,file)
S3method(polish_content_pptx,file_html)
S3method(polish_content_pptx,file_jpeg)
S3method(polish_content_pptx,file_md)
S3method(polish_content_pptx,file_pdf)
S3method(polish_content_pptx,file_png)
S3method(polish_content_pptx,file_rtf)
S3method(polish_content_pptx,file_svg)
S3method(polish_content_pptx,file_txt)
S3method(polish_content_pptx,flextable)
S3method(polish_content_pptx,ggplot)
S3method(polish_content_pptx,list)
S3method(polish_content_pptx,numeric)
S3method(polish_content_word,as_is)
S3method(polish_content_word,as_md)
S3method(polish_content_word,character)
S3method(polish_content_word,data.frame)
S3method(polish_content_word,default)
S3method(polish_content_word,file)
S3method(polish_content_word,file_docx)
S3method(polish_content_word,file_html)
S3method(polish_content_word,file_jpeg)
S3method(polish_content_word,file_md)
S3method(polish_content_word,file_png)
S3method(polish_content_word,file_rtf)
S3method(polish_content_word,file_svg)
S3method(polish_content_word,file_txt)
S3method(polish_content_word,flextable)
S3method(polish_content_word,ggplot)
S3method(polish_content_word,gt_group)
S3method(polish_content_word,gt_tbl)
S3method(polish_content_word,numeric)
S3method(print,file)
S3method(print,polish_xml_nodeset)
export(as_file)
export(as_is)
export(as_md)
export(as_xml_node)
export(as_xml_node_pptx)
export(as_xml_node_word)
export(as_xml_nodeset)
export(as_xml_pptx)
export(as_xml_word)
export(polish_content)
export(polish_content_pptx)
export(polish_content_word)
export(show_xml)
export(sp_shell)
export(xml_nodeset_ns_spec)
import(cli)
import(glue)
import(htmltools)
import(rlang)
importFrom(commonmark,markdown_xml)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(dplyr,na_if)
importFrom(dplyr,slice)
importFrom(flextable,dim_pretty)
importFrom(flextable,flextable)
importFrom(flextable,height)
importFrom(flextable,height_all)
importFrom(flextable,nrow_part)
importFrom(flextable,width)
importFrom(ggplot2,ggsave)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(gt,as_word)
importFrom(gt,grp_pull)
importFrom(gt,vec_fmt_markdown)
importFrom(purrr,imap)
importFrom(purrr,map)
importFrom(sloop,s3_dispatch)
importFrom(tibble,tibble)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,browseURL)
importFrom(utils,capture.output)
importFrom(utils,getFromNamespace)
importFrom(xml2,"xml_attr<-")
importFrom(xml2,read_xml)
importFrom(xml2,xml_add_child)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_attrs)
importFrom(xml2,xml_child)
importFrom(xml2,xml_children)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
importFrom(xml2,xml_name)
importFrom(xml2,xml_ns)
importFrom(xml2,xml_remove)
importFrom(xml2,xml_replace)
importFrom(xml2,xml_text)
