# polish_content_pptx(<flextable>)

    Code
      polished_ft
    Output
      <p:graphicFrame xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:p="http://schemas.openxmlformats.org/presentationml/2006/main">
        <p:nvGraphicFramePr>
          <p:cNvPr id="[...]"/>
          <p:cNvGraphicFramePr>
            <a:graphicFrameLocks noGrp="true"/>
          </p:cNvGraphicFramePr>
          <p:nvPr/>
        </p:nvGraphicFramePr>
        <p:xfrm rot="0">
          <a:off x="[...]" y="[...]"/>
          <a:ext cx="[...]" cy="[...]"/>
        </p:xfrm>
        <a:graphic>
          <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/table">
            <a:tbl>
              <a:tblPr/>
              <a:tblGrid>
                <a:gridCol w="[...]"/>
                <a:gridCol w="[...]"/>
              </a:tblGrid>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>x</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>y</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>1</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>a</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>2</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>b</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>3</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>c</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
            </a:tbl>
          </a:graphicData>
        </a:graphic>
      </p:graphicFrame>

# polish_content_pptx(<flextable>) applied table styling id

    Code
      polished_ft
    Output
      <p:graphicFrame xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:p="http://schemas.openxmlformats.org/presentationml/2006/main">
        <p:nvGraphicFramePr>
          <p:cNvPr id="[...]"/>
          <p:cNvGraphicFramePr>
            <a:graphicFrameLocks noGrp="true"/>
          </p:cNvGraphicFramePr>
          <p:nvPr/>
        </p:nvGraphicFramePr>
        <p:xfrm rot="0">
          <a:off x="[...]" y="[...]"/>
          <a:ext cx="[...]" cy="[...]"/>
        </p:xfrm>
        <a:graphic>
          <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/table">
            <a:tbl>
              <a:tblPr>
                <a:tableStyleId>{291DBC07-340B-ACF5-F4C7-67FE120D59C4}</a:tableStyleId>
              </a:tblPr>
              <a:tblGrid>
                <a:gridCol w="[...]"/>
                <a:gridCol w="[...]"/>
              </a:tblGrid>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>x</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>y</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>1</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>a</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>2</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>b</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>3</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>c</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                </a:tc>
              </a:tr>
            </a:tbl>
          </a:graphicData>
        </a:graphic>
      </p:graphicFrame>

# polish_content_pptx(<flextable>) applied table styling option

    Code
      polished_ft
    Output
      <p:graphicFrame xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:p="http://schemas.openxmlformats.org/presentationml/2006/main">
        <p:nvGraphicFramePr>
          <p:cNvPr id="[...]"/>
          <p:cNvGraphicFramePr>
            <a:graphicFrameLocks noGrp="true"/>
          </p:cNvGraphicFramePr>
          <p:nvPr/>
        </p:nvGraphicFramePr>
        <p:xfrm rot="0">
          <a:off x="[...]" y="[...]"/>
          <a:ext cx="[...]" cy="[...]"/>
        </p:xfrm>
        <a:graphic>
          <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/table">
            <a:tbl>
              <a:tblPr firstRow="1"/>
              <a:tblGrid>
                <a:gridCol w="[...]"/>
                <a:gridCol w="[...]"/>
              </a:tblGrid>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>x</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>y</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>1</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>a</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>2</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>b</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>3</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>c</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
            </a:tbl>
          </a:graphicData>
        </a:graphic>
      </p:graphicFrame>

---

    Code
      polish_content_pptx(ft, table_style = list(options = "Invalid Option"))
    Output
      <p:graphicFrame xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:p="http://schemas.openxmlformats.org/presentationml/2006/main">
        <p:nvGraphicFramePr>
          <p:cNvPr id="[...]"/>
          <p:cNvGraphicFramePr>
            <a:graphicFrameLocks noGrp="true"/>
          </p:cNvGraphicFramePr>
          <p:nvPr/>
        </p:nvGraphicFramePr>
        <p:xfrm rot="0">
          <a:off x="[...]" y="[...]"/>
          <a:ext cx="[...]" cy="[...]"/>
        </p:xfrm>
        <a:graphic>
          <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/table">
            <a:tbl>
              <a:tblPr/>
              <a:tblGrid>
                <a:gridCol w="[...]"/>
                <a:gridCol w="[...]"/>
              </a:tblGrid>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>x</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>y</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>1</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>a</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>2</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>b</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="r" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>3</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="63500" marR="63500">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="500"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="500"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>c</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="63500" marT="63500" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
            </a:tbl>
          </a:graphicData>
        </a:graphic>
      </p:graphicFrame>

# polish_content_pptx(<flextable>) for tables with empty rows

    Code
      polished_ft
    Output
      <p:graphicFrame xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:p="http://schemas.openxmlformats.org/presentationml/2006/main">
        <p:nvGraphicFramePr>
          <p:cNvPr id="[...]"/>
          <p:cNvGraphicFramePr>
            <a:graphicFrameLocks noGrp="true"/>
          </p:cNvGraphicFramePr>
          <p:nvPr/>
        </p:nvGraphicFramePr>
        <p:xfrm rot="0">
          <a:off x="[...]" y="[...]"/>
          <a:ext cx="[...]" cy="[...]"/>
        </p:xfrm>
        <a:graphic>
          <a:graphicData uri="http://schemas.openxmlformats.org/drawingml/2006/table">
            <a:tbl>
              <a:tblPr/>
              <a:tblGrid>
                <a:gridCol w="[...]"/>
                <a:gridCol w="[...]"/>
              </a:tblGrid>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>x</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>y</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>1</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>a</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>2</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>b</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>3</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>c</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:endParaRPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                        <a:solidFill>
                          <a:srgbClr val="000000">
                            <a:alpha val="100000"/>
                          </a:srgbClr>
                        </a:solidFill>
                        <a:latin typeface="[...]"/>
                        <a:cs typeface="[...]"/>
                        <a:ea typeface="[...]"/>
                        <a:sym typeface="[...]"/>
                      </a:endParaRPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t/>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:endParaRPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                        <a:solidFill>
                          <a:srgbClr val="000000">
                            <a:alpha val="100000"/>
                          </a:srgbClr>
                        </a:solidFill>
                        <a:latin typeface="[...]"/>
                        <a:cs typeface="[...]"/>
                        <a:ea typeface="[...]"/>
                        <a:sym typeface="[...]"/>
                      </a:endParaRPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t/>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
              <a:tr h="[...]">
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>5</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
                <a:tc>
                  <a:txBody>
                    <a:bodyPr/>
                    <a:lstStyle/>
                    <a:p>
                      <a:pPr algn="l" marL="12700" marR="12700">
                        <a:lnSpc>
                          <a:spcPct val="100000"/>
                        </a:lnSpc>
                        <a:spcBef>
                          <a:spcPts val="0"/>
                        </a:spcBef>
                        <a:spcAft>
                          <a:spcPts val="0"/>
                        </a:spcAft>
                        <a:buNone/>
                      </a:pPr>
                      <a:r>
                        <a:rPr cap="none" sz="1100" i="0" b="0" u="none" strike="noStrike">
                          <a:solidFill>
                            <a:srgbClr val="000000">
                              <a:alpha val="100000"/>
                            </a:srgbClr>
                          </a:solidFill>
                          <a:latin typeface="[...]"/>
                          <a:cs typeface="[...]"/>
                          <a:ea typeface="[...]"/>
                          <a:sym typeface="[...]"/>
                        </a:rPr>
                        <a:t>e</a:t>
                      </a:r>
                    </a:p>
                  </a:txBody>
                  <a:tcPr anchor="ctr" marB="0" marT="0" marR="0" marL="0">
                    <a:lnL algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnL>
                    <a:lnR algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnR>
                    <a:lnT algn="ctr" cmpd="sng" cap="flat" w="0">
                      <a:noFill/>
                      <a:prstDash val="solid"/>
                    </a:lnT>
                    <a:lnB algn="ctr" cmpd="sng" cap="flat" w="19050">
                      <a:solidFill>
                        <a:srgbClr val="666666">
                          <a:alpha val="100000"/>
                        </a:srgbClr>
                      </a:solidFill>
                      <a:prstDash val="solid"/>
                    </a:lnB>
                    <a:solidFill>
                      <a:srgbClr val="FFFFFF">
                        <a:alpha val="0"/>
                      </a:srgbClr>
                    </a:solidFill>
                  </a:tcPr>
                </a:tc>
              </a:tr>
            </a:tbl>
          </a:graphicData>
        </a:graphic>
      </p:graphicFrame>

